@@ -5,7 +5,7 @@ BEGIN {
   $KiokuDB::Backend::DBI::AUTHORITY = 'cpan:NUFFIN';
 }
 {
-  $KiokuDB::Backend::DBI::VERSION = '1.21';
+  $KiokuDB::Backend::DBI::VERSION = '1.22';
 }
 use Moose;
 
@@ -22,6 +22,7 @@ use Data::Stream::Bulk::DBI;
 use SQL::Abstract;
 use JSON;
 use Scalar::Util qw(weaken refaddr);
+use List::MoreUtils qw(any);
 
 use KiokuDB::Backend::DBI::Schema;
 use KiokuDB::TypeMap;
@@ -694,7 +695,10 @@ sub get {
         );
     }
 
-    return if @rows_and_ids != keys %entries; # ->rows only works after we're done
+    # ->rows only works after we're done
+    return if @rows_and_ids != keys %entries;
+    # case sensitivity differences, possibly?
+    return if any { !defined } @entries{@rows_and_ids};
 
     map { ref($_) ? $_ : $self->deserialize($_) } @entries{@rows_and_ids};
 }
@@ -1088,7 +1092,7 @@ For more details see L<DBIx::Class::Schema::KiokuDB>.
 =head1 SUPPORTED DATABASES
 
 This driver has been tested with MySQL 5 (4.1 should be the minimal supported
-version), SQLite 3, and PostgresSQL 8.3.
+version), SQLite 3, and PostgreSQL 8.3.
 
 The SQL code is reasonably portable and should work with most databases. Binary
 column support is required when using the L<Storable> serializer.
